@@ -15,6 +15,7 @@ class TestDecideBaseTemplate(TestCase):
         """
         request = mock.Mock()
         request.resolver_match.kwargs.get.return_value = None
+        request.path = '/'
         context = context_processors.decide_base_template(request)
         self.assertEqual(context['base_template'], "test.html")
 
@@ -24,6 +25,7 @@ class TestDecideBaseTemplate(TestCase):
         """
         request = mock.Mock()
         request.resolver_match.kwargs.get.return_value = None
+        request.path = '/'
         context = context_processors.decide_base_template(request)
         self.assertEqual(context['base_template'], "base_site.html")
 
@@ -46,6 +48,7 @@ class TestDecideBaseTemplate(TestCase):
         """
         request = mock.Mock()
         request.resolver_match.kwargs.get.side_effect = Exception('something')
+        request.path = '/'
         context_processors.decide_base_template(request)
         template_override_mock.assert_not_called()
 
@@ -63,3 +66,22 @@ class TestDecideBaseTemplate(TestCase):
         self.assertEqual(
             context['base_template'], 'site-1/base_site.html'
         )
+
+    @mock.patch('site_config.context_processors.website_override_template')
+    def test_website_pulled_from_path_if_no_site_kwarg(self,
+                                                       template_override_mock):
+        """
+        If website name isn't in kwargs, extract as first element of URL path
+        """
+        mock_template = mock.Mock()
+        mock_template.name = 'site-2/base_site.html'
+        template_override_mock.return_value = mock_template
+        request = mock.Mock()
+        request.path = '/site-2/something/kinda/long/'
+        request.resolver_match.kwargs.get.side_effect = Exception('something')
+        context = context_processors.decide_base_template(request)
+        template_override_mock.assert_called_once_with(
+            'base_site.html', 'site-2')
+        self.assertEqual(
+            context['base_template'], 'site-2/base_site.html'
+        )
